package net.plil.clubinfo.etunicorn.app.event;

import android.app.Dialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v4.app.DialogFragment;
import android.support.v7.app.AlertDialog;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.android.volley.AuthFailureError;
import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;

import net.plil.clubinfo.etunicorn.R;
import net.plil.clubinfo.etunicorn.app.MainActivity;
import net.plil.clubinfo.etunicorn.app.NFCSupport;
import net.plil.clubinfo.etunicorn.data.Event;
import net.plil.clubinfo.etunicorn.utils.VolleyUtils;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;


public class PaiementEvent extends DialogFragment implements NFCSupport {

    ProgressBar mProgressBar;
    TextView mPaiementEventName;
    TextView mPaiementEventPrice;
    int eventId;

    public PaiementEvent() {
    }

    public static PaiementEvent newInstance(Event event) {
        PaiementEvent f = new PaiementEvent();
        Bundle args = new Bundle();
        args.putSerializable("event", event);
        f.setArguments(args);
        return f;
    }


    @Override
    @NonNull
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        // Use the Builder class for convenient dialog construction
        LayoutInflater inflater = getActivity().getLayoutInflater();
        View view = inflater.inflate(R.layout.fragment_paiment_event, null);
        mProgressBar = (ProgressBar) view.findViewById(R.id.paiment_event_progress_bar);
        mPaiementEventName = (TextView) view.findViewById(R.id.paiment_event_name);
        mPaiementEventPrice = (TextView) view.findViewById(R.id.paiment_event_price);


        Event event = (Event) getArguments().getSerializable("event");
        assert event != null;

        mPaiementEventName.setText(event.getNomEvent());
        mPaiementEventPrice.setText(String.format(Locale.US, "%.2f €", event.getPrice()));

        eventId = event.getIdEvent();

        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());
        builder
                .setTitle(R.string.payment_event)
                .setView(view)
                .setNegativeButton(R.string.cancel, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        VolleyUtils.getInstance(getContext()).getRequestQueue().cancelAll(PaiementEvent.class);
                    }
                });
        Dialog dialog = builder.create();
        dialog.setCanceledOnTouchOutside(false);
        return dialog;
    }


    public void processNFC(String idCardUser) {
        mProgressBar.setVisibility(View.VISIBLE);
        JSONObject jsonObject = new JSONObject();
        try {
            jsonObject.put("participant", idCardUser);
            jsonObject.put("id", eventId);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JsonObjectRequest jsonObjectRequest = new JsonObjectRequest(Request.Method.POST, VolleyUtils.baseUri + "/transaction/evenement", jsonObject, new Response.Listener<JSONObject>() {
            @Override
            public void onResponse(JSONObject response) {
                mProgressBar.setVisibility(View.GONE);
                Toast.makeText(getContext(), R.string.payment_done, Toast.LENGTH_LONG).show();
                dismiss();
            }
        }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                mProgressBar.setVisibility(View.GONE);
                Toast.makeText(getContext(), R.string.payment_refused, Toast.LENGTH_LONG).show();
            }
        }
        ) {
            @Override
            public Map<String, String> getHeaders() throws AuthFailureError {
                Map<String, String> headers = new HashMap<>();
                headers.put("Authorization", MainActivity.session.getToken());
                return headers;
            }
        };

        jsonObjectRequest.setTag(PaiementEvent.class);
        VolleyUtils.getInstance(getContext()).addToRequestQueue(jsonObjectRequest);
    }


    @Override
    public void onStop() {
        VolleyUtils.getInstance(getContext()).getRequestQueue().cancelAll(PaiementEvent.class);
        dismissAllowingStateLoss();
        super.onStop();
    }


}
