package net.plil.clubinfo.etunicorn.app.credit;

import android.content.Context;
import android.os.Bundle;
import android.support.design.widget.CoordinatorLayout;
import android.support.design.widget.Snackbar;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.EditText;
import android.widget.ProgressBar;

import com.android.volley.AuthFailureError;
import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;

import net.plil.clubinfo.etunicorn.R;
import net.plil.clubinfo.etunicorn.app.MainActivity;
import net.plil.clubinfo.etunicorn.app.NFCSupport;
import net.plil.clubinfo.etunicorn.data.Personne;
import net.plil.clubinfo.etunicorn.utils.VolleyUtils;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

public class Crediter extends Fragment implements NFCSupport {

    private EditText mMoneyEditText;
    private ProgressBar mProgressBar;
    private CoordinatorLayout coordinatorLayout;

    public Crediter() {
        // Required empty public constructor
    }

    public static Crediter newInstance() {
        return new Crediter();
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.fragment_crediter, container, false);
        mMoneyEditText = (EditText) view.findViewById(R.id.crediter_ask_money);
        mProgressBar = (ProgressBar) view.findViewById(R.id.crediter_progress_bar);
        coordinatorLayout = (CoordinatorLayout) view.findViewById(R.id.crediter_layout);
        return view;
    }

    @Override
    public void onAttach(Context context) {
        super.onAttach(context);
    }

    @Override
    public void onDetach() {
        super.onDetach();
    }

    @Override
    public void processNFC(String idCardUser) {
        if (mMoneyEditText.getText().toString().isEmpty()) {
            mMoneyEditText.setError(getString(R.string.error_enter_debit));
            return;
        }
        mProgressBar.setVisibility(View.VISIBLE);
        mMoneyEditText.setVisibility(View.GONE);
        JSONObject jsonObject = new JSONObject();
        try {
            Personne p = new Personne();
            p.setCarte(idCardUser);
            jsonObject.put("participant", p);
            jsonObject.put("prix", Double.parseDouble(mMoneyEditText.getText().toString()));
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JsonObjectRequest jsonObjectRequest = new JsonObjectRequest(Request.Method.POST, VolleyUtils.baseUri + "/transaction/debit", jsonObject, new Response.Listener<JSONObject>() {
            @Override
            public void onResponse(JSONObject response) {
                mProgressBar.setVisibility(View.GONE);
                mMoneyEditText.setText("");
                mMoneyEditText.setVisibility(View.VISIBLE);
                Snackbar.make(coordinatorLayout, "DONE", Snackbar.LENGTH_LONG).show();
            }
        }, new Response.ErrorListener() {
            @Override
            public void onErrorResponse(VolleyError error) {
                mProgressBar.setVisibility(View.GONE);
                mMoneyEditText.setVisibility(View.VISIBLE);
                Snackbar.make(coordinatorLayout, error.getMessage(), Snackbar.LENGTH_LONG).show();
            }
        }
        ) {
            @Override
            public Map<String, String> getHeaders() throws AuthFailureError {
                Map<String, String> headers = new HashMap<>();
                headers.put("Authorization", MainActivity.session.getToken());
                return headers;
            }
        };
        jsonObjectRequest.setTag(Crediter.class);
        VolleyUtils.getInstance(getContext()).addToRequestQueue(jsonObjectRequest);
    }

    @Override
    public void onStop() {
        VolleyUtils.getInstance(getContext()).getRequestQueue().cancelAll(Crediter.class);
        super.onStop();
    }
}
